# README

This project was created with [python-webpack-boilerplate](https://github.com/AccordBox/python-webpack-boilerplate)

## Available Scripts

In the project directory, you can run:

### `npm run start`

`npm run start` will launch a server process, which makes `live reloading` possible.

If you change JS or SCSS files, the web page would auto refresh after the change. Now the server is working on port 9091 by default, but you can change it in `webpack/webpack.config.dev.js`

### `npm run watch`

run webpack in `watch` mode.

### `npm run build`

[production mode](https://webpack.js.org/guides/production/), Webpack would focus on minified bundles, lighter weight source maps, and optimized assets to improve load time.
